@@ -1,17 +1,60 @@
 package codespace
 
 import (
+	"bytes"
 	"context"
 	"fmt"
 	"testing"
 	"time"
 
+	"github.com/cli/cli/v2/internal/browser"
 	"github.com/cli/cli/v2/internal/codespaces/api"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
+	"github.com/google/shlex"
 	"github.com/stretchr/testify/assert"
 )
 
+func TestCreateCmdFlagError(t *testing.T) {
+	tests := []struct {
+		name     string
+		args     string
+		wantsErr error
+	}{
+		{
+			name:     "return error when using web flag with display-name, idle-timeout, or retention-period flags",
+			args:     "--web --display-name foo --idle-timeout 30m",
+			wantsErr: fmt.Errorf("using --web with --display-name, --idle-timeout, or --retention-period is not supported"),
+		},
+		{
+			name:     "return error when using web flag with one of display-name, idle-timeout or retention-period flags",
+			args:     "--web --idle-timeout 30m",
+			wantsErr: fmt.Errorf("using --web with --display-name, --idle-timeout, or --retention-period is not supported"),
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			ios, _, _, _ := iostreams.Test()
+			a := &App{
+				io: ios,
+			}
+			cmd := newCreateCmd(a)
+
+			args, _ := shlex.Split(tt.args)
+			cmd.SetArgs(args)
+			cmd.SetIn(&bytes.Buffer{})
+			cmd.SetOut(&bytes.Buffer{})
+			cmd.SetErr(&bytes.Buffer{})
+
+			_, err := cmd.ExecuteC()
+
+			assert.Error(t, err)
+			assert.EqualError(t, err, tt.wantsErr.Error())
+		})
+	}
+}
+
 func TestApp_Create(t *testing.T) {
 	type fields struct {
 		apiClient apiClient
@@ -23,6 +66,7 @@ func TestApp_Create(t *testing.T) {
 		wantErr    error
 		wantStdout string
 		wantStderr string
+		wantURL    string
 		isTTY      bool
 	}{
 		{
@@ -57,6 +101,7 @@ func TestApp_Create(t *testing.T) {
 				retentionPeriod: NullableDuration{durationPtr(48 * time.Hour)},
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 		},
 		{
 			name: "create with explicit display name",
@@ -78,6 +123,7 @@ func TestApp_Create(t *testing.T) {
 				displayName: "funky flute",
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 		},
 		{
 			name: "create codespace with default branch shows idle timeout notice if present",
@@ -111,6 +157,32 @@ func TestApp_Create(t *testing.T) {
 				devContainerPath: ".devcontainer/foobar/devcontainer.json",
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
+		},
+		{
+			name: "create codespace with nonexistent machine results in error",
+			fields: fields{
+				apiClient: apiCreateDefaults(&apiClientMock{
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
+						return []*api.Machine{
+							{
+								Name:        "GIGA",
+								DisplayName: "Gigabits of a machine",
+							},
+							{
+								Name:        "TERA",
+								DisplayName: "Terabits of a machine",
+							},
+						}, nil
+					},
+				}),
+			},
+			opts: createOptions{
+				repo:    "monalisa/dotfiles",
+				machine: "MEGA",
+			},
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
+			wantErr:    fmt.Errorf("error getting machine type: there is no such machine for the repository: %s\nAvailable machines: %v", "MEGA", []string{"GIGA", "TERA"}),
 		},
 		{
 			name: "create codespace with devcontainer path results in selecting the correct machine type",
@@ -172,6 +244,7 @@ func TestApp_Create(t *testing.T) {
 				devContainerPath: ".devcontainer/foobar/devcontainer.json",
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 		},
 		{
 			name: "create codespace with default branch with default devcontainer if no path provided and no devcontainer files exist in the repo",
@@ -205,7 +278,7 @@ func TestApp_Create(t *testing.T) {
 				idleTimeout: 30 * time.Minute,
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
-			wantStderr: "Notice: Idle timeout for this codespace is set to 10 minutes in compliance with your organization's policy\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\nNotice: Idle timeout for this codespace is set to 10 minutes in compliance with your organization's policy\n",
 			isTTY:      true,
 		},
 		{
@@ -224,7 +297,8 @@ func TestApp_Create(t *testing.T) {
 				showStatus:  false,
 				idleTimeout: 30 * time.Minute,
 			},
-			wantErr: fmt.Errorf("error getting devcontainer.json paths: some error"),
+			wantErr:    fmt.Errorf("error getting devcontainer.json paths: some error"),
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 		},
 		{
 			name: "create codespace with default branch does not show idle timeout notice if not conntected to terminal",
@@ -252,7 +326,7 @@ func TestApp_Create(t *testing.T) {
 				idleTimeout: 30 * time.Minute,
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
-			wantStderr: "",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 			isTTY:      false,
 		},
 		{
@@ -280,7 +354,8 @@ func TestApp_Create(t *testing.T) {
 				idleTimeout: 30 * time.Minute,
 			},
 			wantErr: cmdutil.SilentError,
-			wantStderr: `You must authorize or deny additional permissions requested by this codespace before continuing.
+			wantStderr: `  ✓ Codespaces usage for this repository is paid for by monalisa
+You must authorize or deny additional permissions requested by this codespace before continuing.
 Open this URL in your browser to review and authorize additional permissions: example.com/permissions
 Alternatively, you can run "create" with the "--default-permissions" option to continue without authorizing additional permissions.
 `,
@@ -304,7 +379,31 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 			wantErr: fmt.Errorf("error checking codespace ownership: some error"),
 		},
 		{
-			name: "mentions billable owner when org covers codepaces for a repository",
+			name: "mentions User as billable owner when org does not cover codepaces for a repository",
+			fields: fields{
+				apiClient: apiCreateDefaults(&apiClientMock{
+					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
+						return &api.User{
+							Type:  "User",
+							Login: "monalisa",
+						}, nil
+					},
+					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
+						return &api.Codespace{
+							Name: "monalisa-dotfiles-abcd1234",
+						}, nil
+					},
+				}),
+			},
+			opts: createOptions{
+				repo:   "monalisa/dotfiles",
+				branch: "main",
+			},
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
+			wantStdout: "monalisa-dotfiles-abcd1234\n",
+		},
+		{
+			name: "mentions Organization as billable owner when org covers codepaces for a repository",
 			fields: fields{
 				apiClient: apiCreateDefaults(&apiClientMock{
 					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
@@ -330,7 +429,117 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 			wantStderr: "  ✓ Codespaces usage for this repository is paid for by megacorp\n",
 			wantStdout: "megacorp-private-abcd1234\n",
 		},
+		{
+			name: "does not mention billable owner when not an expected type",
+			fields: fields{
+				apiClient: apiCreateDefaults(&apiClientMock{
+					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
+						return &api.User{
+							Type:  "UnexpectedBillableOwnerType",
+							Login: "mega-owner",
+						}, nil
+					},
+					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
+						return &api.Codespace{
+							Name: "megacorp-private-abcd1234",
+						}, nil
+					},
+				}),
+			},
+			opts: createOptions{
+				repo: "megacorp/private",
+			},
+			wantStdout: "megacorp-private-abcd1234\n",
+		},
+		{
+			name: "return default url when using web flag without other flags",
+			opts: createOptions{
+				useWeb: true,
+			},
+			wantURL: "https://github.com/codespaces/new",
+		},
+		{
+			name: "skip machine check when using web flag and no machine provided",
+			fields: fields{
+				apiClient: apiCreateDefaults(&apiClientMock{
+					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
+						return &api.Repository{
+							ID:            123,
+							DefaultBranch: "main",
+						}, nil
+					},
+					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
+						return &api.Codespace{
+							Name: "monalisa-dotfiles-abcd1234",
+						}, nil
+					},
+				}),
+			},
+			opts: createOptions{
+				repo:     "monalisa/dotfiles",
+				useWeb:   true,
+				branch:   "custom",
+				location: "EastUS",
+			},
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
+			wantURL:    fmt.Sprintf("https://github.com/codespaces/new?repo=%d&ref=%s&machine=%s&location=%s", 123, "custom", "", "EastUS"),
+		},
+		{
+			name: "return correct url with correct params when using web flag and repo flag",
+			fields: fields{
+				apiClient: apiCreateDefaults(&apiClientMock{
+					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
+						return &api.Repository{
+							ID:            123,
+							DefaultBranch: "main",
+						}, nil
+					},
+					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
+						return &api.Codespace{
+							Name: "monalisa-dotfiles-abcd1234",
+						}, nil
+					},
+				}),
+			},
+			opts: createOptions{
+				repo:   "monalisa/dotfiles",
+				useWeb: true,
+			},
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
+			wantURL:    fmt.Sprintf("https://github.com/codespaces/new?repo=%d&ref=%s&machine=%s&location=%s", 123, "main", "", ""),
+		},
+		{
+			name: "return correct url with correct params when using web flag, repo, branch, location, machine flag",
+			fields: fields{
+				apiClient: apiCreateDefaults(&apiClientMock{
+					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
+						return &api.Repository{
+							ID:            123,
+							DefaultBranch: "main",
+						}, nil
+					},
+					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
+						return &api.Codespace{
+							Name:    "monalisa-dotfiles-abcd1234",
+							Machine: api.CodespaceMachine{Name: "GIGA"},
+						}, nil
+					},
+				}),
+			},
+			opts: createOptions{
+				repo:     "monalisa/dotfiles",
+				machine:  "GIGA",
+				branch:   "custom",
+				location: "EastUS",
+				useWeb:   true,
+			},
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
+			wantURL:    fmt.Sprintf("https://github.com/codespaces/new?repo=%d&ref=%s&machine=%s&location=%s", 123, "custom", "GIGA", "EastUS"),
+		},
 	}
+	var a *App
+	var b *browser.Stub
+
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			ios, _, stdout, stderr := iostreams.Test()
@@ -338,9 +547,18 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 			ios.SetStdinTTY(tt.isTTY)
 			ios.SetStderrTTY(tt.isTTY)
 
-			a := &App{
-				io:        ios,
-				apiClient: tt.fields.apiClient,
+			if tt.opts.useWeb {
+				b = &browser.Stub{}
+				a = &App{
+					io:        ios,
+					apiClient: tt.fields.apiClient,
+					browser:   b,
+				}
+			} else {
+				a = &App{
+					io:        ios,
+					apiClient: tt.fields.apiClient,
+				}
 			}
 
 			err := a.Create(context.Background(), tt.opts)
@@ -358,6 +576,10 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 				t.Logf(t.Name())
 				t.Errorf("  stderr = %v, want %v", got, tt.wantStderr)
 			}
+
+			if tt.opts.useWeb {
+				b.Verify(t, tt.wantURL)
+			}
 		})
 	}
 }
