@@ -20,6 +20,7 @@ import (
 	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/google/shlex"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestNewCmdView(t *testing.T) {
@@ -1381,18 +1382,36 @@ func Test_attachRunLog(t *testing.T) {
 			},
 			wantMatch: false,
 		},
+		{
+			name: "job name with forward slash matches dir with slash removed",
+			job: shared.Job{
+				Name: "cool job / with slash",
+				Steps: []shared.Step{{
+					Name:   "fob the barz",
+					Number: 1,
+				}},
+			},
+			wantMatch: true,
+			// not the double space in the dir name, as the slash has been removed
+			wantFilename: "cool job  with slash/1_fob the barz.txt",
+		},
 	}
-	rlz, _ := zip.OpenReader("./fixtures/run_log.zip")
+
+	rlz, err := zip.OpenReader("./fixtures/run_log.zip")
+	require.NoError(t, err)
 	defer rlz.Close()
+
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			attachRunLog(rlz, []shared.Job{tt.job})
+
+			attachRunLog(&rlz.Reader, []shared.Job{tt.job})
+
 			for _, step := range tt.job.Steps {
 				log := step.Log
 				logPresent := log != nil
-				assert.Equal(t, tt.wantMatch, logPresent)
+				require.Equal(t, tt.wantMatch, logPresent)
 				if logPresent {
-					assert.Equal(t, tt.wantFilename, log.Name)
+					require.Equal(t, tt.wantFilename, log.Name)
 				}
 			}
 		})
